@@ -2,6 +2,6 @@
 from .base_url import BaseUrl
 from .key import Key
 from .yoonik_api_exception import YoonikApiException
-from .http_requests import request
+from .http_requests import request, request_async
 from .api_result import ApiResult
 from .face_authentication import FaceAuthentication
